@@ -3,7 +3,7 @@ import sys
 import zipfile
 import argparse
 from pathlib import Path
-from api_server import api_server
+from atp.api_server import api_server
 
 
 def main():
@@ -16,7 +16,7 @@ def main():
     parser.add_argument('-s', '--server', help='Start X-ATP automated test execution side service', action='store_true')
     args = parser.parse_args()
     if args.version:
-        print("Current client version: v0.1.8")
+        print("Current client version: v0.1.9")
     if args.demo:
         x_sweetest_dir = Path(__file__).resolve().parents[0]
         example_dir = x_sweetest_dir / 'example' / 'x_sweetest_example.zip'
