@@ -8,6 +8,7 @@ from x_sweetest.log import logger
 from x_sweetest.parse import data_format
 from x_sweetest.utility import json2dict
 from pathlib import Path
+from requests_toolbelt.multipart.encoder import MultipartEncoder
 
 path = Path('lib') / 'http_handle.py'
 if path.is_file():
@@ -134,8 +135,21 @@ def request(kw, step):
             logger.info(f'PARAMS: {_data["params"]}')
 
     elif kw == 'post':
-        r = getattr(http.r, kw)(http.baseurl + url,
-                                data=_data['data'], json=_data['json'], files=_data['files'], timeout=timeout, **data)
+        if 'form' in data:
+            form_dict = json2dict(data['form'])
+            try:
+                if len(form_dict) == 1:
+                    for form_k, form_v in form_dict.items():
+                        form_name = form_k.split("/")[-1]
+                form_data = MultipartEncoder(fields={'file': (form_name, open(form_k, 'rb'), form_v)})
+                form_headers = {'Content-Type': form_data.content_type}
+                http.r.headers.update(form_headers)
+                r = getattr(http.r, kw)(http.baseurl + url, data=form_data, timeout=timeout)
+            except:
+                logger.exception("***form can be only one Key-value***")
+        else:
+            r = getattr(http.r, kw)(http.baseurl + url,
+                                    data=_data['data'], json=_data['json'], files=_data['files'], timeout=timeout, **data)
         logger.info(f'BODY: {r.request.body}')
 
     elif kw in ('put', 'patch'):
